@@ -18,7 +18,8 @@ from django.utils.decorators import method_decorator
 
 from ..utils import log, ddns_client
 from ..main.models import Host
-from ..main.dnstools import update, SameIpError, DnsUpdateError, NameServerNotAvailable, check_ip, put_ip_into_session
+from ..main.dnstools import (update, delete, check_ip, put_ip_into_session,
+                             SameIpError, DnsUpdateError, NameServerNotAvailable)
 
 
 def Response(content):
@@ -111,10 +112,12 @@ def basic_authenticate(auth):
     :param auth: http basic auth string
     :return: username, password
     """
+    auth = auth.decode('utf-8')
     authmeth, auth = auth.split(' ', 1)
     if authmeth.lower() != 'basic':
         return
-    auth = auth.strip().decode('base64')
+    from base64 import b64decode
+    auth = b64decode(auth.strip()).decode('utf-8')
     username, password = auth.split(':', 1)
     return username, password
 
@@ -129,7 +132,7 @@ def check_api_auth(username, password):
     """
     fqdn = username
     try:
-        host = Host.filter_by_fqdn(fqdn)
+        host = Host.get_by_fqdn(fqdn)
     except ValueError:
         return None
     if host is None or not check_password(password, host.update_secret):
@@ -147,7 +150,7 @@ def check_session_auth(user, hostname):
     """
     fqdn = hostname
     try:
-        host = Host.filter_by_fqdn(fqdn, created_by=user)
+        host = Host.get_by_fqdn(fqdn, created_by=user)
     except ValueError:
         return None
     # we have specifically looked for a host of the logged in user,
@@ -157,7 +160,7 @@ def check_session_auth(user, hostname):
 
 class NicUpdateView(View):
     @log.logger(__name__)
-    def get(self, request, logger=None):
+    def get(self, request, logger=None, delete=False):
         """
         dyndns2 compatible /nic/update API.
 
@@ -180,6 +183,7 @@ class NicUpdateView(View):
         https://fqdn:secret@nsupdate.info/nic/update?hostname=fqdn&myip=1.2.3.4
 
         :param request: django request object
+        :param delete: False means update, True means delete - used by NicDeleteView
         :return: HttpResponse object
         """
         hostname = request.GET.get('hostname')
@@ -216,10 +220,31 @@ class NicUpdateView(View):
             host.register_client_fault()
             return Response('badagent')
         ipaddr = request.GET.get('myip')
-        if ipaddr is None:
+        if not ipaddr:  # None or ''
             ipaddr = request.META.get('REMOTE_ADDR')
-        ssl = request.is_secure()
-        return _update(host, hostname, ipaddr, ssl, logger=logger)
+        secure = request.is_secure()
+        if delete:
+            return _delete(host, hostname, ipaddr, secure, logger=logger)
+        else:
+            return _update(host, hostname, ipaddr, secure, logger=logger)
+
+
+class NicDeleteView(NicUpdateView):
+    @log.logger(__name__)
+    def get(self, request, logger=None, delete=True):
+        """
+        /nic/delete API - delete a A or AAAA record.
+
+        API is pretty much the same as for /nic/update, but it does not update
+        the A or AAAA record, but deletes it.
+        The ip address given via myip= param (or determined via REMOTE_ADDR)
+        is used to determine the record type for deletion, but is otherwise
+        ignored (so you can e.g. give myip=0.0.0.0 for A and myip=:: for AAAA).
+
+        :param request: django request object
+        :return: HttpResponse object
+        """
+        return super(NicDeleteView, self).get(request, logger=logger, delete=delete)
 
 
 class AuthorizedNicUpdateView(View):
@@ -229,7 +254,7 @@ class AuthorizedNicUpdateView(View):
         return super(AuthorizedNicUpdateView, self).dispatch(*args, **kwargs)
 
     @log.logger(__name__)
-    def get(self, request, logger=None):
+    def get(self, request, logger=None, delete=False):
         """
         similar to NicUpdateView, but the client is not a router or other dyndns client,
         but the admin browser who is currently logged into the nsupdate.info site.
@@ -239,6 +264,7 @@ class AuthorizedNicUpdateView(View):
         https://nsupdate.info/nic/update?hostname=fqdn&myip=1.2.3.4
 
         :param request: django request object
+        :param delete: False means update, True means delete - used by AuthorizedNicDeleteView
         :return: HttpResponse object
         """
         hostname = request.GET.get('hostname')
@@ -254,18 +280,34 @@ class AuthorizedNicUpdateView(View):
         ipaddr = request.GET.get('myip')
         if not ipaddr:  # None or empty string
             ipaddr = request.META.get('REMOTE_ADDR')
-        ssl = request.is_secure()
-        return _update(host, hostname, ipaddr, ssl, logger=logger)
+        secure = request.is_secure()
+        if delete:
+            return _delete(host, hostname, ipaddr, secure, logger=logger)
+        else:
+            return _update(host, hostname, ipaddr, secure, logger=logger)
 
 
-def _update(host, hostname, ipaddr, ssl=False, logger=None):
+class AuthorizedNicDeleteView(AuthorizedNicUpdateView):
+
+    @log.logger(__name__)
+    def get(self, request, logger=None, delete=True):
+        """
+        /nic/delete API - for logged-in admin browser.
+
+        :param request: django request object
+        :return: HttpResponse object
+        """
+        return super(AuthorizedNicDeleteView, self).get(request, logger=logger, delete=delete)
+
+
+def _update(host, hostname, ipaddr, secure=False, logger=None):
     """
     common code shared by the 2 update views
 
     :param host: host object
     :param hostname: hostname (fqdn)
     :param ipaddr: new ip addr (v4 or v6)
-    :param ssl: True if we use SSL/https
+    :param secure: True if we use TLS/https
     :param logger: a logger object
     :return: Response object with dyndns2 response
     """
@@ -277,14 +319,20 @@ def _update(host, hostname, ipaddr, ssl=False, logger=None):
     if not host.available:
         # not available is like it doesn't exist
         return Response('nohost')
-    ipaddr = str(ipaddr)  # bug in dnspython: crashes if ipaddr is unicode, wants a str!
-                          # https://github.com/rthalley/dnspython/issues/41
-                          # TODO: reproduce and submit traceback to issue 41
-    kind = check_ip(ipaddr, ('ipv4', 'ipv6'))
-    host.poke(kind, ssl)
+    try:
+        # bug in dnspython: crashes if ipaddr is unicode, wants a str!
+        # https://github.com/rthalley/dnspython/issues/41
+        # TODO: reproduce and submit traceback to issue 41
+        ipaddr = str(ipaddr)
+        kind = check_ip(ipaddr, ('ipv4', 'ipv6'))
+    except (ValueError, UnicodeError):
+        # invalid ip address string
+        # some people manage to even give a non-ascii string instead of an ip addr
+        return Response('dnserr')  # there should be a better response code for this
+    host.poke(kind, secure)
     try:
         update(hostname, ipaddr)
-        logger.info('%s - received good update -> ip: %s ssl: %r' % (hostname, ipaddr, ssl))
+        logger.info('%s - received good update -> ip: %s tls: %r' % (hostname, ipaddr, secure))
         # now check if there are other services we shall relay updates to:
         for hc in host.serviceupdaterhostconfigs.all():
             if (kind == 'ipv4' and hc.give_ipv4 and hc.service.accept_ipv4
@@ -303,12 +351,56 @@ def _update(host, hostname, ipaddr, ssl=False, logger=None):
                     logger.exception("the dyndns2 updater raised an exception [%r]" % kwargs)
         return Response('good %s' % ipaddr)
     except SameIpError:
-        logger.warning('%s - received no-change update, ip: %s ssl: %r' % (hostname, ipaddr, ssl))
+        logger.warning('%s - received no-change update, ip: %s tls: %r' % (hostname, ipaddr, secure))
         host.register_client_fault()
         return Response('nochg %s' % ipaddr)
     except (DnsUpdateError, NameServerNotAvailable) as e:
         msg = str(e)
-        logger.error('%s - received update that resulted in a dns error [%s], ip: %s ssl: %r' % (
-                     hostname, msg, ipaddr, ssl))
+        logger.error('%s - received update that resulted in a dns error [%s], ip: %s tls: %r' % (
+                     hostname, msg, ipaddr, secure))
+        host.register_server_fault()
+        return Response('dnserr')
+
+
+def _delete(host, hostname, ipaddr, secure=False, logger=None):
+    """
+    common code shared by the 2 delete views
+
+    :param host: host object
+    :param hostname: hostname (fqdn)
+    :param ipaddr: ip addr (to determine record type A or AAAA)
+    :param secure: True if we use TLS/https
+    :param logger: a logger object
+    :return: Response object with dyndns2 response
+    """
+    # we are doing abuse / available checks rather late, so the client might
+    # get more specific responses (like 'badagent' or 'notfqdn') by earlier
+    # checks. it also avoids some code duplication if done here:
+    if host.abuse or host.abuse_blocked:
+        return Response('abuse')
+    if not host.available:
+        # not available is like it doesn't exist
+        return Response('nohost')
+    try:
+        # bug in dnspython: crashes if ipaddr is unicode, wants a str!
+        # https://github.com/rthalley/dnspython/issues/41
+        # TODO: reproduce and submit traceback to issue 41
+        ipaddr = str(ipaddr)
+        kind = check_ip(ipaddr, ('ipv4', 'ipv6'))
+    except (ValueError, UnicodeError):
+        # invalid ip address string
+        # some people manage to even give a non-ascii string instead of an ip addr
+        return Response('dnserr')  # there should be a better response code for this
+    host.poke(kind, secure)
+    try:
+        rdtype = 'A' if kind == 'ipv4' else 'AAAA'
+        delete(hostname, rdtype)
+        logger.info('%s - received delete for record %s, tls: %r' % (hostname, rdtype, secure))
+        # XXX unclear what to do for "other services" we relay updates to
+        return Response('deleted %s' % rdtype)
+    except (DnsUpdateError, NameServerNotAvailable) as e:
+        msg = str(e)
+        logger.error('%s - received delete for record %s that resulted in a dns error [%s], tls: %r' % (
+                     hostname, rdtype, msg, secure))
         host.register_server_fault()
         return Response('dnserr')
