@@ -2,6 +2,10 @@
 Tests for main views module.
 """
 
+from __future__ import print_function
+
+import pytest
+
 from django.core.urlresolvers import reverse
 
 
@@ -13,7 +17,6 @@ def test_views_anon(client):
     for view, kwargs, status_code in [
         ('home', dict(), 200),
         ('about', dict(), 200),
-        ('legal', dict(), 200),
         ('robots', dict(), 200),
         # stuff that requires being logged-in redirects to the login view:
         ('status', dict(), 302),
@@ -31,7 +34,7 @@ def test_views_anon(client):
         # interactive updater shows http basic auth popup
         ('update', dict(), 401),
     ]:
-        print view, kwargs, status_code
+        print("%s, %s, %s" % (view, kwargs, status_code))
         response = client.get(reverse(view, kwargs=kwargs))
         assert response.status_code == status_code
 
@@ -41,7 +44,6 @@ def test_views_logged_in(client):
     for view, kwargs, status_code in [
         ('home', dict(), 200),
         ('about', dict(), 200),
-        ('legal', dict(), 200),
         ('robots', dict(), 200),
         ('status', dict(), 200),
         ('overview', dict(), 200),
@@ -57,6 +59,6 @@ def test_views_logged_in(client):
         ('delete_updater_hostconfig', dict(pk=1), 200),
         ('update', dict(), 401),
     ]:
-        print view, kwargs, status_code
+        print("%s, %s, %s" % (view, kwargs, status_code))
         response = client.get(reverse(view, kwargs=kwargs))
         assert response.status_code == status_code
