@@ -36,6 +36,7 @@ from django.utils.timezone import now
 
 
 Timeout = dns.resolver.Timeout
+NoNameservers = dns.resolver.NoNameservers
 
 
 class SameIpError(ValueError):
@@ -174,6 +175,10 @@ def query_ns(qname, rdtype, origin=None):
     resolver.nameservers = [nameserver, ]
     resolver.search = []
     resolver.lifetime = RESOLVER_TIMEOUT
+    # as we query directly the (authoritative) master dns, we do not desire
+    # recursion. But: RD (recursion desired) is the internal default for flags
+    # (used if flags = None is given). Thus, we explicitly give flags (all off):
+    resolver.flags = 0
     try:
         answer = resolver.query(fqdn, rdtype)
         ip = str(list(answer)[0])
@@ -310,6 +315,10 @@ def update_ns(fqdn, rdtype='A', ipaddr=None, origin=None, action='upd', ttl=60):
         logger.error("PeerBadSignature - shared secret mismatch? zone: %s" % (origin, ))
         set_ns_availability(domain, False)
         raise DnsUpdateError("PeerBadSignature")
+    except dns.message.UnknownTSIGKey as e:
+        logger.error("UnknownTSIGKey [%s] - zone: %s" % (str(e), origin, ))
+        set_ns_availability(domain, False)
+        raise DnsUpdateError("UnknownTSIGKey")
 
 
 def set_ns_availability(domain, available):
