@@ -99,7 +99,8 @@ class Domain(models.Model):
         algorithm = self.nameserver_update_algorithm
         bitlength = UPDATE_ALGORITHMS[algorithm].bitlength
         user_model = get_user_model()
-        secret = user_model.objects.make_random_password(length=bitlength / 8)
+        secret = user_model.objects.make_random_password(length=bitlength // 8)
+        secret = secret.encode('utf-8')
         self.nameserver_update_secret = secret_base64 = base64.b64encode(secret)
         self.save()
         return secret_base64
@@ -164,8 +165,8 @@ class Host(models.Model):
     last_update_ipv4 = models.DateTimeField(blank=True, null=True)
     last_update_ipv6 = models.DateTimeField(blank=True, null=True)
     # how we received the last update for v4/v6 addr
-    ssl_update_ipv4 = models.BooleanField(default=False)
-    ssl_update_ipv6 = models.BooleanField(default=False)
+    tls_update_ipv4 = models.BooleanField(default=False)
+    tls_update_ipv6 = models.BooleanField(default=False)
 
     last_update = models.DateTimeField(auto_now=True)
     created = models.DateTimeField(auto_now_add=True)
@@ -176,33 +177,35 @@ class Host(models.Model):
             self.subdomain, self.domain.domain)
 
     class Meta(object):
-        unique_together = (('subdomain', 'domain'),)
+        unique_together = (('subdomain', 'domain'), )
+        index_together = (('subdomain', 'domain'), )
 
     def get_fqdn(self):
         return '%s.%s' % (self.subdomain, self.domain.domain)
 
     @classmethod
-    def filter_by_fqdn(cls, fqdn, **kwargs):
+    def get_by_fqdn(cls, fqdn, **kwargs):
         # Assuming subdomain has no dots (.) the fqdn is split at the first dot
         splitted = fqdn.split('.', 1)
-        if not len(splitted) == 2:
-            raise ValueError("FQDN has to contain (at least) one dot")
-        hosts = Host.objects.filter(
-            subdomain=splitted[0], domain__domain=splitted[1], **kwargs)
-        count = len(hosts)
-        if count == 0:
+        if len(splitted) != 2:
+            raise ValueError("get_by_fqdn(%s): FQDN has to contain (at least) one dot" % fqdn)
+        try:
+            host = Host.objects.get(subdomain=splitted[0], domain__domain=splitted[1], **kwargs)
+        except Host.DoesNotExist:
             return None
-        if count == 1:
-            return hosts[0]
-        if count > 1:
-            raise ValueError("filter_by_fqdn(%s) found more than 1 host" % fqdn)
+        except Host.MultipleObjectsReturned:
+            # should not happen, see Meta.unique_together
+            raise ValueError("get_by_fqdn(%s) found more than 1 host" % fqdn)
+        else:
+            return host
 
     def get_ip(self, kind):
         record = 'A' if kind == 'ipv4' else 'AAAA'
         try:
             return dnstools.query_ns(self.get_fqdn(), record, origin=self.domain.domain)
-        except (dns.resolver.NXDOMAIN, dns.resolver.NoAnswer, dns.resolver.NoNameservers, dns.resolver.Timeout,
-                dnstools.NameServerNotAvailable):
+        except (dns.resolver.NXDOMAIN, dns.resolver.NoAnswer):
+            return 'none'
+        except (dns.resolver.NoNameservers, dns.resolver.Timeout, dnstools.NameServerNotAvailable):
             return 'error'
 
     def get_ipv4(self):
@@ -211,13 +214,13 @@ class Host(models.Model):
     def get_ipv6(self):
         return self.get_ip('ipv6')
 
-    def poke(self, kind, ssl):
+    def poke(self, kind, secure):
         if kind == 'ipv4':
             self.last_update_ipv4 = now()
-            self.ssl_update_ipv4 = ssl
+            self.tls_update_ipv4 = secure
         else:
             self.last_update_ipv6 = now()
-            self.ssl_update_ipv6 = ssl
+            self.tls_update_ipv6 = secure
         self.save()
 
     def register_client_fault(self, increment=1):
@@ -231,7 +234,7 @@ class Host(models.Model):
     def generate_secret(self, secret=None):
         # note: we use a quick hasher for the update_secret as expensive
         # more modern hashes might put too much load on the servers. also
-        # many update clients might use http without ssl, so it is not too
+        # many update clients might use http without tls, so it is not too
         # secure anyway.
         if secret is None:
             user_model = get_user_model()
@@ -275,7 +278,7 @@ class ServiceUpdater(models.Model):
         help_text="Update Server URL path of this service")
     secure = models.BooleanField(
         default=True,
-        help_text="Use https / SSL to contact the Update Server?")
+        help_text="Use https / TLS to contact the Update Server?")
 
     # what kind(s) of IPs is (are) acceptable to this service:
     accept_ipv4 = models.BooleanField(default=False)
