@@ -8,9 +8,10 @@ from django.views.generic import TemplateView
 from .views import (
     HomeView, OverviewView, HostView, DeleteHostView, AboutView, GenerateSecretView, GenerateNSSecretView,
     RobotsTxtView, DomainOverviewView, DomainView, DeleteDomainView, StatusView, JsUpdateView,
-    UpdaterHostConfigOverviewView, UpdaterHostConfigView, DeleteUpdaterHostConfigView)
+    UpdaterHostConfigOverviewView, UpdaterHostConfigView, DeleteUpdaterHostConfigView, CustomTemplateView)
 from ..api.views import (
-    myip_view, DetectIpView, AjaxGetIps, NicUpdateView, AuthorizedNicUpdateView)
+    myip_view, DetectIpView, AjaxGetIps, NicUpdateView, AuthorizedNicUpdateView,
+    NicDeleteView, AuthorizedNicDeleteView)
 
 
 urlpatterns = patterns(
@@ -18,7 +19,7 @@ urlpatterns = patterns(
     # interactive web ui
     url(r'^$', HomeView.as_view(), name="home"),
     url(r'^about/$', AboutView.as_view(), name="about"),
-    url(r'^legal/$', TemplateView.as_view(template_name='main/legal.html'), name="legal"),
+    url(r'^custom/(?P<template>[\w.]+)$', CustomTemplateView.as_view(), name="custom"),
     url(r'^update$', JsUpdateView.as_view(), name='update'),
     url(r'^overview/$', OverviewView.as_view(), name='overview'),
     url(r'^host/(?P<pk>\d+)/$', HostView.as_view(), name='host_view'),
@@ -38,9 +39,11 @@ urlpatterns = patterns(
     url(r'^detectip/(?P<sessionid>\w+)/$', DetectIpView.as_view(), name='detectip'),
     url(r'^ajax_get_ips/$', AjaxGetIps.as_view(), name="ajax_get_ips"),
     url(r'^nic/update_authorized$', AuthorizedNicUpdateView.as_view(), name='nic_update_authorized'),
+    url(r'^nic/delete_authorized$', AuthorizedNicDeleteView.as_view(), name='nic_delete_authorized'),
     # api (for update clients)
     url(r'^myip$', myip_view, name='myip'),
     url(r'^nic/update$', NicUpdateView.as_view(), name='nic_update'),
+    url(r'^nic/delete$', NicDeleteView.as_view(), name='nic_delete'),  # api extension
     # for bots
     url(r'^robots.txt$', RobotsTxtView.as_view(), name='robots'),
 )
