@@ -3,6 +3,7 @@
 views for the interactive web user interface
 """
 
+import socket
 from datetime import timedelta
 
 from django.db.models import Q
@@ -17,7 +18,7 @@ from django.core.urlresolvers import reverse
 from django.core.exceptions import PermissionDenied
 from django.utils.timezone import now
 
-import dnstools
+from . import dnstools
 
 from .forms import (CreateHostForm, EditHostForm, CreateDomainForm, EditDomainForm,
                     CreateUpdaterHostConfigForm, EditUpdaterHostConfigForm)
@@ -80,6 +81,14 @@ class AboutView(TemplateView):
         return context
 
 
+class CustomTemplateView(TemplateView):
+    # template_name is set in dispatch method
+
+    def dispatch(self, *args, **kwargs):
+        self.template_name = 'main/custom/%s' % kwargs.get('template')
+        return super(CustomTemplateView, self).dispatch(*args, **kwargs)
+
+
 class HomeView(TemplateView):
     template_name = "main/home.html"
 
@@ -114,20 +123,20 @@ class StatusView(TemplateView):
         before_2y = t_now - timedelta(days=730)
         context['hosts_ipv4_2d'] = Host.objects.filter(last_update_ipv4__gt=before_2d).count()
         context['hosts_ipv6_2d'] = Host.objects.filter(last_update_ipv6__gt=before_2d).count()
-        context['hosts_ipv4_ssl_2d'] = Host.objects.filter(last_update_ipv4__gt=before_2d, ssl_update_ipv4=True).count()
-        context['hosts_ipv6_ssl_2d'] = Host.objects.filter(last_update_ipv6__gt=before_2d, ssl_update_ipv6=True).count()
+        context['hosts_ipv4_tls_2d'] = Host.objects.filter(last_update_ipv4__gt=before_2d, tls_update_ipv4=True).count()
+        context['hosts_ipv6_tls_2d'] = Host.objects.filter(last_update_ipv6__gt=before_2d, tls_update_ipv6=True).count()
         context['hosts_ipv4_2w'] = Host.objects.filter(last_update_ipv4__gt=before_2w).count()
         context['hosts_ipv6_2w'] = Host.objects.filter(last_update_ipv6__gt=before_2w).count()
-        context['hosts_ipv4_ssl_2w'] = Host.objects.filter(last_update_ipv4__gt=before_2w, ssl_update_ipv4=True).count()
-        context['hosts_ipv6_ssl_2w'] = Host.objects.filter(last_update_ipv6__gt=before_2w, ssl_update_ipv6=True).count()
+        context['hosts_ipv4_tls_2w'] = Host.objects.filter(last_update_ipv4__gt=before_2w, tls_update_ipv4=True).count()
+        context['hosts_ipv6_tls_2w'] = Host.objects.filter(last_update_ipv6__gt=before_2w, tls_update_ipv6=True).count()
         context['hosts_ipv4_2m'] = Host.objects.filter(last_update_ipv4__gt=before_2m).count()
         context['hosts_ipv6_2m'] = Host.objects.filter(last_update_ipv6__gt=before_2m).count()
-        context['hosts_ipv4_ssl_2m'] = Host.objects.filter(last_update_ipv4__gt=before_2m, ssl_update_ipv4=True).count()
-        context['hosts_ipv6_ssl_2m'] = Host.objects.filter(last_update_ipv6__gt=before_2m, ssl_update_ipv6=True).count()
+        context['hosts_ipv4_tls_2m'] = Host.objects.filter(last_update_ipv4__gt=before_2m, tls_update_ipv4=True).count()
+        context['hosts_ipv6_tls_2m'] = Host.objects.filter(last_update_ipv6__gt=before_2m, tls_update_ipv6=True).count()
         context['hosts_ipv4_2y'] = Host.objects.filter(last_update_ipv4__gt=before_2y).count()
         context['hosts_ipv6_2y'] = Host.objects.filter(last_update_ipv6__gt=before_2y).count()
-        context['hosts_ipv4_ssl_2y'] = Host.objects.filter(last_update_ipv4__gt=before_2y, ssl_update_ipv4=True).count()
-        context['hosts_ipv6_ssl_2y'] = Host.objects.filter(last_update_ipv6__gt=before_2y, ssl_update_ipv6=True).count()
+        context['hosts_ipv4_tls_2y'] = Host.objects.filter(last_update_ipv4__gt=before_2y, tls_update_ipv4=True).count()
+        context['hosts_ipv6_tls_2y'] = Host.objects.filter(last_update_ipv6__gt=before_2y, tls_update_ipv6=True).count()
         user_model = get_user_model()
         context['users_total'] = user_model.objects.count()
         context['users_active'] = user_model.objects.filter(is_active=True).count()
@@ -190,6 +199,15 @@ class OverviewView(CreateView):
             success, level, msg = False, messages.ERROR, 'Timeout - communicating to name server failed.'
         except dnstools.NameServerNotAvailable:
             success, level, msg = False, messages.ERROR, 'Name server unavailable.'
+        except dnstools.NoNameservers:
+            success, level, msg = False, messages.ERROR, 'Resolving failed: No name servers.'
+        except dnstools.DnsUpdateError as e:
+            success, level, msg = False, messages.ERROR, 'DNS update error [%s].' % str(e)
+        except Domain.DoesNotExist:
+            # should not happen: POST data had invalid (base)domain
+            success, level, msg = False, messages.ERROR, 'Base domain does not exist.'
+        except socket.error as err:
+            success, level, msg = False, messages.ERROR, 'Communication to name server failed [%s]' % str(err)
         else:
             self.object.created_by = self.request.user
             self.object.save()
