@@ -7,9 +7,9 @@ from .base import *
 DEBUG = False
 TEMPLATE_DEBUG = DEBUG
 
-WE_HAVE_SSL = True  # True if you run a https site also, suggest that site to users if they work on the http site.
-CSRF_COOKIE_SECURE = WE_HAVE_SSL
-SESSION_COOKIE_SECURE = WE_HAVE_SSL
+WE_HAVE_TLS = True  # True if you run a https site also, suggest that site to users if they work on the http site.
+CSRF_COOKIE_SECURE = WE_HAVE_TLS
+SESSION_COOKIE_SECURE = WE_HAVE_TLS
 
 # these are the service host names we deal with
 BASEDOMAIN = 'nsupdate.info'
@@ -19,5 +19,5 @@ WWW_IPV4_HOST = 'ipv4.' + BASEDOMAIN  # a host with ONLY a ipv4 address
 WWW_IPV6_HOST = 'ipv6.' + BASEDOMAIN  # a host with ONLY a ipv6 address
 
 # Hosts/domain names that are valid for this site; required if DEBUG is False
-# See https://docs.djangoproject.com/en/1.5/ref/settings/#allowed-hosts
+# See https://docs.djangoproject.com/en/1.6/ref/settings/#allowed-hosts
 ALLOWED_HOSTS = [WWW_HOST, WWW_IPV4_HOST, WWW_IPV6_HOST]
